@@ -14,11 +14,10 @@ In F<config.yaml>
 
   actions:
     ...
-    - view
+    view:
+      class: SVN::Web::View
     ...
 
-  view_class: SVN::Web::View
-
 =head1 DESCRIPTION
 
 Shows a specific revision of a file in the Subversion repository.  Includes
